@@ -34,7 +34,7 @@
 #include "translucentbutton.h"
 
 #ifdef DORIAN_TEST_MODEL
-#include "modeltest.h"
+#   include "modeltest.h"
 #endif
 
 #ifdef Q_WS_MAC
@@ -44,7 +44,7 @@
 #endif
 
 const int PROGRESS_HEIGHT = 17;
-const char *DORIAN_VERSION =
+static const char *DORIAN_VERSION =
 #include "pkg/version.txt"
 ;
 
@@ -73,22 +73,19 @@ MainWindow::MainWindow(QWidget *parent):
     // Progress
     progress = new Progress(central);
 
-    // Tool bar
-
-    setUnifiedTitleAndToolBarOnMac(true);
+    // Settings dialog
     settings = new QDialog(this);
-    toolBar = addToolBar("controls");
-    toolBar->setMovable(false);
-    toolBar->setFloatable(false);
-    toolBar->toggleViewAction()->setVisible(false);
-#if defined(Q_WS_X11) && !defined(Q_WS_MAEMO_5)
-    toolBar->setIconSize(QSize(42, 42));
-#endif
 
-    chaptersAction = addToolBarAction(this, SLOT(showChapters()), "chapters");
-    bookmarksAction = addToolBarAction(this, SLOT(showBookmarks()), "bookmarks");
-    infoAction = addToolBarAction(this, SLOT(showInfo()), "info");
-    libraryAction = addToolBarAction(this, SLOT(showLibrary()), "library");
+    // Tool bar actions
+
+    chaptersAction = addToolBarAction(this, SLOT(showChapters()),
+                                      "chapters", tr("Chapters"));
+    bookmarksAction = addToolBarAction(this, SLOT(showBookmarks()),
+                                       "bookmarks", tr("Bookmarks"));
+    infoAction = addToolBarAction(this, SLOT(showInfo()),
+                                  "info", tr("Book info"));
+    libraryAction = addToolBarAction(this, SLOT(showLibrary()),
+                                     "library", tr("Library"));
 
 #ifdef Q_WS_MAEMO_5
     settingsAction = menuBar()->addAction(tr("Settings"));
@@ -99,17 +96,15 @@ MainWindow::MainWindow(QWidget *parent):
     connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));
 #else
     settingsAction = addToolBarAction(this, SLOT(showSettings()),
-                                      "preferences-system");
-    devToolsAction = addToolBarAction(this, SLOT(showDevTools()), "developer");
-    addToolBarAction(this, SLOT(about()), "about");
+                                      "preferences-system", tr("Settings"));
+    devToolsAction = addToolBarAction(this, SLOT(showDevTools()),
+                                      "developer", tr("Developer"));
+    addToolBarAction(this, SLOT(about()), "about", tr("About"));
 #endif // Q_WS_MAEMO_5
 
-    QFrame *frame = new QFrame(toolBar);
-    frame->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    toolBar->addWidget(frame);
-
+    addToolBarSpace();
     fullScreenAction = addToolBarAction(this, SLOT(showBig()),
-                                        "view-fullscreen");
+                                        "view-fullscreen", tr("Full screen"));
 
     // Buttons on top of the book view
     previousButton = new TranslucentButton("back", this);
@@ -189,14 +184,18 @@ void MainWindow::showRegular()
     otherChildren << progress << previousButton << nextButton;
     takeChildren(view, otherChildren);
     QRect geo = geometry();
-    qDebug() << "Geometry" << geo << "toolbar" << toolBar->height();
     progress->setGeometry(0, 0, geo.width(), PROGRESS_HEIGHT);
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     previousButton->setGeometry(0,
         geo.height() - toolBar->height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
     nextButton->setGeometry(geo.width() - TranslucentButton::pixels, 0,
         TranslucentButton::pixels, TranslucentButton::pixels);
+#elif defined(Q_OS_SYMBIAN)
+    previousButton->setGeometry(0, geo.height() - TranslucentButton::pixels,
+        TranslucentButton::pixels, TranslucentButton::pixels);
+    nextButton->setGeometry(geo.width() - TranslucentButton::pixels,
+        0, TranslucentButton::pixels, TranslucentButton::pixels);
 #else
     previousButton->setGeometry(0, geo.height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
@@ -239,14 +238,6 @@ void MainWindow::setCurrentBook(const QModelIndex &current)
     setWindowTitle(book? book->shortName(): tr("Dorian"));
 }
 
-QAction *MainWindow::addToolBarAction(const QObject *receiver,
-                                      const char *member,
-                                      const QString &name)
-{
-    return toolBar->
-        addAction(QIcon(ICON_PREFIX + name + ".png"), "", receiver, member);
-}
-
 void MainWindow::showLibrary()
 {
     (new LibraryDialog(this))->show();
@@ -402,13 +393,17 @@ void MainWindow::resizeEvent(QResizeEvent *e)
 {
     Trace t("MainWindow::resizeEvent");
     progress->setGeometry(QRect(0, 0, e->size().width(), PROGRESS_HEIGHT));
-    qDebug() << "Toolbar height" << toolBar->height();
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     previousButton->setGeometry(0,
         e->size().height() - toolBar->height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
     nextButton->setGeometry(e->size().width() - TranslucentButton::pixels, 0,
         TranslucentButton::pixels, TranslucentButton::pixels);
+#elif defined(Q_OS_SYMBIAN)
+    previousButton->setGeometry(0, e->size().height() - TranslucentButton::pixels,
+        TranslucentButton::pixels, TranslucentButton::pixels);
+    nextButton->setGeometry(e->size().width() - TranslucentButton::pixels,
+        0, TranslucentButton::pixels, TranslucentButton::pixels);
 #else
     previousButton->setGeometry(0, e->size().height() - TranslucentButton::pixels,
         TranslucentButton::pixels, TranslucentButton::pixels);
@@ -428,7 +423,7 @@ void MainWindow::about()
     QLabel *label = new QLabel(aboutDialog);
     label->setTextFormat(Qt::RichText);
     label->setOpenExternalLinks(true);
-    label->setText(tr("<b>Dorian %1</b><br><br>Copyright &copy; 2010 by "
+    label->setText(tr("<b>Dorian %1</b><br><br>Copyright &copy; 2010 "
         "Akos Polster &lt;akos@pipacs.com&gt;<br>"
         "Licensed under GNU General Public License, Version 3<br>"
         "Source code: <a href='https://garage.maemo.org/projects/dorian/'>"
